SuitupColorUtils extension

Some color utils

on

Properties

contrast Color

Available on Color, provided by the SuitupColorUtils extension

This method will apply dark or light color for text depending on the luminance of background color.
no setter
toHex String

Available on Color, provided by the SuitupColorUtils extension

This method will parse this color to a Hexadecimal String representation like: #005522
no setter