suitup library
Classes
- SuitupCancellable
- SuitupColor
-
There is nothing here because this class is only suposed to
exists so the
SuitupTextAbstractcan be instantiated and this abstract class allows the user to override its values - SuitupColorAbstract
- Our default values for colors
- SuitupController
- An extensible controller with auto initialize and dispose method.
-
SuitupListNotifier<
T> -
By default a list inside a
ValueNotifierwill observe its changes only when the list is completely replaced and changes on its items will not take any effect. -
SuitupNotifier<
T extends Object?> -
SuitupNotifierBuilder<
T extends Object?> - SuitupObserver
- This widget is just an alias to the AnimatedBuilder because its name is not intuitive
-
SuitupState<
C extends SuitupController, T extends StatefulWidget> -
A state to automatically run the controller
initializeanddispose - SuitupTextField
-
A simple
TextFormFieldbut formatted to be prettier to me than material default - SuitupTheme
Enums
- SuitupNotifierType
- The four status type of the state
- SuitupStatus
- Some useful statuses to be used on the screen, so you can control the workflow with it
Extensions
- SuitupColorUtils on Color
- Some color utils
- SuitupDoubleUtils on double
- Utils to doubles
- SuitupFileUtils on File
- This extension will allow to get the file extension easily
-
SuitupGlobalKeyEx
on GlobalKey<
State< StatefulWidget> > - This extension supose to retrieve the global position of a widget on the screen
- SuitupStringUtils on String
- Helpers on strings
Properties
Functions
-
dateFormatted(
DateTime date, {String? pattern, String? locale}) → String - Format a date as "16 de Junho às 16:20"
-
debug(
Object? message, {String? label}) → void - This functions is supposed to be used when you want to print something on the debug console, but on the VS Code it will be shown yellow
-
doubleInRange(
num start, num end) → double -
Provides a random double number between
startandend -
executionTime(
DateTime start, [bool echo = true]) → Duration -
This method will calculate the time elapsed from
the
starttill now. -
randomInt(
int start, int end) → int -
Returns a random int number between
startandend -
unfocus(
BuildContext context) → void - Remove the focus on the context